"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const path_1 = __importDefault(require("path"));
module.exports = (options = {}) => {
    let babel;
    const compatibleTypes = ['js', 'jsx', 'ts', 'tsx', 'es', 'es6', 'mjs', 'cjs'];
    return {
        name: 'babel-plugin',
        setup({ resolve, chalk }) {
            const babelPath = resolve(__filename, '@babel/core', {
                mainFields: ['main']
            });
            if (babelPath) {
                babel = require(babelPath);
                options = Object.assign({}, options, {
                    ast: false,
                    sourceMaps: true,
                    sourceType: 'module',
                });
                // Warm up babel
                babel.transformAsync('', options);
            }
            else {
                console.log(chalk.red('You need to install "@babel/core" package in order to use BabelPlugin.'));
                console.log(chalk.red('Please run "npm i @babel/core" to install Babel.'));
            }
        },
        async transformContent(data, filePath) {
            if (!babel)
                return;
            if (compatibleTypes.includes(data.type)) {
                try {
                    const { code, map } = await babel.transformAsync(data.code, options);
                    map.sources = [filePath];
                    return {
                        code,
                        map
                    };
                }
                catch (e) {
                    let message = `BabelPlugin: Error while transforming "${path_1.default.relative(this.config.rootDir, filePath)}"\n`;
                    message += e.message.replace(/^unknown: /, '');
                    return new Error(message);
                }
            }
            return null;
        }
    };
};
